@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2016 onpon4 <onpon4@riseup.net>
+# Copyright (C) 2012-2016 Julie Marchant <onpon4@riseup.net>
 #
 # This file is part of the Pygame SGE.
 #
@@ -136,7 +136,7 @@ def _scale(surface, width, height):
                 break
 
         if new_surf.get_width() != width or new_surf.get_height() != height:
-            new_surf = pygame.transform.scale(surface, (width, height))
+            new_surf = pygame.transform.scale(new_surf, (width, height))
     else:
         new_surf = pygame.transform.scale(surface, (width, height))
 
@@ -619,6 +619,11 @@ def o_update_collision_lists(self):
             collision_checkers = _collision_checkers[:]
             collision_checkers.append(self)
             _collision_checkers = collision_checkers
+        else:
+            collision_checkers = _collision_checkers[:]
+            while self in collision_checkers:
+                collision_checkers.remove(self)
+            _collision_checkers = collision_checkers
     else:
         colliders = _colliders[:]
         while self in colliders:
